@@ -14,9 +14,9 @@ fragment size = read_1 + insert_size + read_2
 
 #import built-in modules
 import os,sys
-if sys.version_info[0] != 2 or sys.version_info[1] != 7:
-	print >>sys.stderr, "\nYou are using python" + str(sys.version_info[0]) + '.' + str(sys.version_info[1]) + " RSeQC needs python2.7!\n"
-	sys.exit()
+if sys.version_info[0] != 3:
+	print("\nYou are using python" + str(sys.version_info[0]) + '.' + str(sys.version_info[1]) + " This verion of RSeQC needs python3!\n", file=sys.stderr)
+	sys.exit()	
 
 import re
 import string
@@ -25,7 +25,6 @@ import warnings
 import string
 import collections
 import math
-import sets
 from time import strftime
 import subprocess
 
@@ -45,7 +44,7 @@ __author__ = "Liguo Wang"
 __copyright__ = "Copyleft"
 __credits__ = []
 __license__ = "GPL"
-__version__="2.6.6"
+__version__="5.0.0"
 __maintainer__ = "Liguo Wang"
 __email__ = "wang.liguo@mayo.edu"
 __status__ = "Production"
@@ -55,8 +54,8 @@ def printlog (mesg):
 	'''print progress into stderr and log file'''
 	mesg="@ " + strftime("%Y-%m-%d %H:%M:%S") + ": " + mesg
 	LOG=open('class.log','a')
-	print >>sys.stderr,mesg
-	print >>LOG,mesg
+	print(mesg, file=sys.stderr)
+	print(mesg, file=LOG)
 
 
 def main():
@@ -78,18 +77,18 @@ def main():
 		sys.exit(0)
 	for input_file in ([options.input_file,options.ref_gene]):
 		if not os.path.exists(input_file):
-			print >>sys.stderr, '\n\n' + input_file + " does NOT exists" + '\n'
+			print('\n\n' + input_file + " does NOT exists" + '\n', file=sys.stderr)
 			parser.print_help()
 			sys.exit(0)
 	if options.step_size <=0:
-		print >>sys.stderr, "step size is a positive interger"
+		print("step size is a positive interger", file=sys.stderr)
 		sys.exit(0)
 	obj = SAM.ParseBAM(options.input_file)
 	obj.mRNA_inner_distance(outfile=options.output_prefix,low_bound=options.lower_bound_size,up_bound=options.upper_bound_size,step=options.step_size,refbed=options.ref_gene,sample_size=options.sampleSize, q_cut = options.map_qual)
 	try:
 		subprocess.call("Rscript " + options.output_prefix + '.inner_distance_plot.r',shell=True)
 	except:
-		print >>sys.stderr, "Cannot generate pdf file from " + options.output_prefix + '.inner_distance_plot.r'
+		print("Cannot generate pdf file from " + options.output_prefix + '.inner_distance_plot.r', file=sys.stderr)
 		pass
 
 if __name__ == '__main__':
