@@ -7,25 +7,19 @@ Mapping-based: Reads mapped to the exact same location are considered as "duplic
 
 #import built-in modules
 import os,sys
-if sys.version_info[0] != 2 or sys.version_info[1] != 7:
-	print >>sys.stderr, "\nYou are using python" + str(sys.version_info[0]) + '.' + str(sys.version_info[1]) + " RSeQC needs python2.7!\n"
-	sys.exit()
+if sys.version_info[0] != 3:
+	print("\nYou are using python" + str(sys.version_info[0]) + '.' + str(sys.version_info[1]) + " This verion of RSeQC needs python3!\n", file=sys.stderr)
+	sys.exit()	
 
 import re
-import string
 from optparse import OptionParser
 import warnings
 import string
 import collections
 import math
-import sets
 from time import strftime
 import subprocess
 
-#import third-party modules
-from bx.bitset import *
-from bx.bitset_builders import *
-from bx.intervals import *
 
 #import my own modules
 from qcmodule import SAM
@@ -38,7 +32,7 @@ __author__ = "Liguo Wang"
 __copyright__ = "Copyleft"
 __credits__ = []
 __license__ = "GPL"
-__version__="2.6.6"
+__version__="5.0.0"
 __maintainer__ = "Liguo Wang"
 __email__ = "wang.liguo@mayo.edu"
 __status__ = "Production"
@@ -48,8 +42,8 @@ def printlog (mesg):
 	'''print progress into stderr and log file'''
 	mesg="@ " + strftime("%Y-%m-%d %H:%M:%S") + ": " + mesg
 	LOG=open('class.log','a')
-	print >>sys.stderr,mesg
-	print >>LOG,mesg
+	print(mesg, file=sys.stderr)
+	print(mesg, file=LOG)
 
 
 def main():
@@ -72,7 +66,7 @@ def main():
 		except:
 			pass
 	else:
-		print >>sys.stderr, '\n\n' + options.input_file + " does NOT exists" + '\n'
+		print('\n\n' + options.input_file + " does NOT exists" + '\n', file=sys.stderr)
 		#parser.print_help()
 		sys.exit(0)
 	
